const eventCenter = new function () {

    const TAG = '[EventCenter]';
    let eventMap = new Map();

    /**
     * 订阅一个消息/事件
     * @param type 类型
     * @param handler 消息处理函数
     * @returns string 订阅id
     */
    this.subscribe = (type, handler) => {
        let listeners = eventMap.get(type);
        if (listeners == null) {
            listeners = [];
            eventMap.set(type, listeners);
        }
        let eventListener = { handler }
        listeners.push(eventListener);
        return () => {
            let idx = listeners.indexOf(eventListener);
            if (idx > -1) {
                listeners.splice(idx, 1);
            }
            if (listeners.length === 0) {
                eventMap.delete(type);
            }
        };
    }


    /**
     * 发布一个消息
     * @param type
     * @param data
     */
    this.dispatch = (type, data) => {
        let listeners = eventMap.get(type);
        (listeners || []).forEach(listener => {
            if (typeof(listener.handler)=='function') {
                try {
                    listener.handler(data);
                } catch (e) {
                    console.error(TAG, `处理消息过程中发生错误`, e);
                }
            }
        });
    }

}();

export default eventCenter;