
const ticatecUtils = new function () {
    /**
     * 判断参数是不是一个函数
     * @param fun
     * @returns {boolean}
     */
    let isFunction = (fun) => {
        return fun instanceof Function;
    }

    /**
     * 调用函数
     * @param fun
     * @param params
     */
    let invokeFunction = (fun, ...params) => {
        if (isFunction(fun)) {
            fun(...params);
        }
    }

    /**
     * 判断字符串是不是空
     * @param s
     * @returns {boolean}
     */
    let isEmpty = (s) => {
        return s == null || s === "" || s.length === 0;
    }

    /**
     * 解析url中的queryString
     * @type {function(*): {}}
     */
    let parseQueryString = (function(d,x,params,p,i,j) {
        return function (qs) {
            params = {};
            let end = qs.indexOf('#');
            if (end === -1) {
                end = qs.length;
            }
            qs = qs.substring(qs.indexOf('?')+1, end).replace(x,' ').split('&');
            for (i = qs.length; i > 0;) {
                p = qs[--i];
                j = p.indexOf('=');
                if(j === -1) params[d(p)] = undefined;
                else params[d(p.substring(0,j))] = d(p.substring(j+1));
            }
            return params;
        };
    })(decodeURIComponent, /\+/g);

    /**
     * 增加空白属性
     * @param obj
     * @param attrs
     * @returns {*}
     */
    this.addEmptyAttrs = (obj, attrs) => {
        attrs.forEach((attr)=>{obj[attr]=''});
        return obj;
    }

    /**
     * 深度克隆
     * @param obj
     * @returns {any}
     */
    this.deepClone = (obj) =>  {
        return JSON.parse(JSON.stringify(obj));
    }

    /**
     * 把obj2中的属性增加或替换obj1的同名属性
     * @param obj1
     * @param obj2
     * @param props
     * @returns {*}
     */
    this.copy = (obj1, obj2, props) => {
        (props || []).forEach(prop => {
            obj1[prop] = obj2[prop];
        });
        return obj1;
    }


    this.isFunction = isFunction;
    this.invokeFunction = invokeFunction;
    this.isEmpty = isEmpty;
    this.parseQueryString = parseQueryString;
}();

export default ticatecUtils;